@@ -28,6 +28,11 @@ class Servico:
             return (response, response.json()) if response.ok else (response, {})
         return (response, response.json()[0])
 
+    def ativo(self):
+        response = mindset_request('GET', '/servicos', query_params={'servico': self.nome_servico})
+        if response.ok and response.json():
+            return response.json()[0]['ativo']
+
     @staticmethod
     def filtrar(filter_params={}):
         return mindset_request('GET', '/servicos', query_params=filter_params)
